import { Controller, Post, UseInterceptors, UploadedFiles } from '@nestjs/common';
import { FilesInterceptor } from '@nestjs/platform-express';
import { diskStorage } from 'multer';
import { extname, resolve } from 'path';
import { UploadService } from './upload.service';

@Controller('upload')
export class UploadController {
  constructor(private readonly uploadSrvice: UploadService) {}
  @Post()
  @UseInterceptors(
    FilesInterceptor('files', 10, { // Accept multiple files with a limit of 10
      storage: diskStorage({
        destination: './uploads', // Save files in the "uploads" folder
        filename: (req, file, callback) => {
          const uniqueSuffix = Date.now() + '-' + Math.round(Math.random() * 1e9);
          const ext = extname(file.originalname);
          const filename = `${file.fieldname}-${uniqueSuffix}${ext}`;
          callback(null, filename);
        },
      }),
    }),
  )
  async uploadFiles(@UploadedFiles() files: Express.Multer.File[]) {
    console.log('Files uploaded:', files);
    return this.uploadSrvice.getEmotion(files);
  }
}
