import { useState } from "react";
import UploadFileField from "./UploadFileField";
import SubmitButton from "./SubmitButton";

function FileUploadContainer() {
    const [file1, setFile1] = useState<File | null>(null);
    const [isUploading, setIsUploading] = useState(false);
    const [uploadSuccess, setUploadSuccess] = useState<boolean | null>(null);
    const [data, setData] = useState<object | null>(null);  // Use state for data

    async function handleUpload() {
        setIsUploading(true);
        setUploadSuccess(null);
        
        const formData = new FormData();
        if (file1) {
            formData.append("files", file1);
        }

        try {
            const response = await fetch("http://localhost:3000/upload", {
                method: "POST",
                body: formData,
            });

            if (response.ok) {
                const responseData = await response.json();
                setData(responseData);  // Update state
                setUploadSuccess(true);
            } else {
                console.error("Failed to upload files.");
                setUploadSuccess(false);
            }
        } catch (error) {
            console.error("Error uploading files:", error);
            setUploadSuccess(false);
        } finally {
            setIsUploading(false);
        }
    }

    return (
        <div className="flex flex-col gap-4">
            {!isUploading && uploadSuccess === null && (
                <>
                    <div className="self-start">
                      <UploadFileField buttonText="Upload video" onFileSelect={setFile1} />
                    </div>
                    
                    <SubmitButton onClick={handleUpload} disabled={!file1} />
                </>
            )}
            {isUploading && (
                <div className="flex justify-center w-full">
                  <div className="w-10 h-10 border-4 border-blue-500 border-t-transparent rounded-full animate-spin mt-5"></div>
                </div>   
            )}
            {uploadSuccess !== null && !isUploading && (
                data ? (
                    <>
                        <p className="text-center mt-5">The emotion detected in the file provided is:</p>
                        <div className="text-center mt-2">
                          <span className="bg-white text-gray-800 py-2 px-4 rounded-lg text-center font-semibold text-lg">
                              {(data as any).classification}
                          </span>
                        </div>
                    </>
                ) : (
                    <p className="text-center mt-5 text-red-500">Upload failed. Please try again.</p>
                )
            )}
        </div>
    );
}

export default FileUploadContainer;
