import { useState } from "react";
import { Upload } from "lucide-react";

interface FileUploadProps {
  buttonText: string;
  onFileSelect: (file: File | null) => void;
}

function UploadFileField({ buttonText, onFileSelect }: FileUploadProps) {
  const [file, setFile] = useState<File | null>(null);

  const inputId: string = `file-upload-${Math.random().toString(36).substring(2, 9)}`;

  function handleFileChange(event: React.ChangeEvent<HTMLInputElement>) {
    if (event.target.files && event.target.files.length > 0) {
      const selectedFile = event.target.files[0];
      setFile(selectedFile);
      onFileSelect(selectedFile);
    } else {
      setFile(null);
      onFileSelect(null);
    }
  }

  return (
    <div className="flex flex-col gap-4 mt-3">
      <div className="flex items-center gap-4">
        <input
          type="file"
          id={inputId}
          className="hidden"
          onChange={handleFileChange}
        />
        <label htmlFor={inputId} className="cursor-pointer">
          <div className="flex items-center gap-2 px-6 py-3 text-lg rounded-2xl shadow-md bg-gray-900 text-white hover:bg-gray-800 transition-all">
            <Upload size={20} />
            {buttonText}
          </div>
        </label>
        {file && <p className="text-gray-400">Selected file: {file.name}</p>}
      </div>
    </div>
  );
}

export default UploadFileField;