import React from "react";

interface VideoBackgroundProps {
  videoSrc: string; // Path to the video file
  transparency?: number; // Opacity of the video (0 to 1)
  children?: React.ReactNode; // Content to display on top of the video
}

function VideoBackground({ videoSrc, transparency = 1, children }: VideoBackgroundProps) {
  return (
    <div style={{ position: "fixed", top: 0, left: 0, width: "100vw", height: "100vh", overflow: "hidden" }}>
      {/* Background Video */}
      <video
        autoPlay
        muted
        loop
        style={{
          position: "absolute",
          top: "50%",
          left: "50%",
          width: "100%",
          height: "100%",
          objectFit: "cover",
          transform: "translate(-50%, -50%)",
          zIndex: -1,
          opacity: transparency, // Set the transparency of the video
        }}
      >
        <source src={videoSrc} type="video/mp4" />
        Your browser does not support the video tag.
      </video>

      {/* Content on top of the video */}
      <div
        style={{
          position: "relative",
          zIndex: 1,
          color: "white",
          textAlign: "left",
          height: "100vh",
          display: "flex",
          flexDirection: "column",
          justifyContent: "center",
          alignItems: "center",
        }}
      >
        {children}
      </div>
    </div>
  );
}

export default VideoBackground;